======================
bodhi-expire-overrides
======================

Synopsis
========

``bodhi-expire-overrides CONFIG_FILE``


Description
===========

``bodhi-expire-overrides`` searches for overrides that are past their expiration date and marks them
as expired.


Help
====

If you find bugs in bodhi (or in the man page), please feel free to file a bug report or a pull
request:

    https://github.com/fedora-infra/bodhi

Bodhi's documentation is available online: https://bodhi.fedoraproject.org/docs
